@@ -15,13 +15,10 @@
   along with grf. If not, see <http://www.gnu.org/licenses/>.
  #-------------------------------------------------------------------------------*/
 
-#include <map>
 #include <Rcpp.h>
-#include <sstream>
 #include <vector>
 
 #include "commons/globals.h"
-#include "Eigen/Sparse"
 #include "forest/ForestPredictors.h"
 #include "forest/ForestTrainers.h"
 #include "RcppUtilities.h"
@@ -29,8 +26,7 @@
 using namespace grf;
 
 // [[Rcpp::export]]
-Rcpp::List regression_train(Rcpp::NumericMatrix train_matrix,
-                            Eigen::SparseMatrix<double> sparse_train_matrix,
+Rcpp::List regression_train(const Rcpp::NumericMatrix& train_matrix,
                             size_t outcome_index,
                             size_t sample_weight_index,
                             bool use_sample_weights,
@@ -51,76 +47,70 @@ Rcpp::List regression_train(Rcpp::NumericMatrix train_matrix,
                             unsigned int seed) {
   ForestTrainer trainer = regression_trainer();
 
-  std::unique_ptr<Data> data = RcppUtilities::convert_data(train_matrix, sparse_train_matrix);
-  data->set_outcome_index(outcome_index - 1);
-  if(use_sample_weights) {
-      data->set_weight_index(sample_weight_index - 1);
+  Data data = RcppUtilities::convert_data(train_matrix);
+  data.set_outcome_index(outcome_index);
+  if (use_sample_weights) {
+    data.set_weight_index(sample_weight_index);
   }
 
   ForestOptions options(num_trees, ci_group_size, sample_fraction, mtry, min_node_size, honesty,
       honesty_fraction, honesty_prune_leaves, alpha, imbalance_penalty, num_threads, seed, clusters, samples_per_cluster);
-  Forest forest = trainer.train(*data, options);
+  Forest forest = trainer.train(data, options);
 
   std::vector<Prediction> predictions;
   if (compute_oob_predictions) {
     ForestPredictor predictor = regression_predictor(num_threads);
-    predictions = predictor.predict_oob(forest, *data, false);
+    predictions = predictor.predict_oob(forest, data, false);
   }
 
   return RcppUtilities::create_forest_object(forest, predictions);
 }
 
 // [[Rcpp::export]]
-Rcpp::List regression_predict(Rcpp::List forest_object,
-                              Rcpp::NumericMatrix train_matrix,
-                              Eigen::SparseMatrix<double> sparse_train_matrix,
+Rcpp::List regression_predict(const Rcpp::List& forest_object,
+                              const Rcpp::NumericMatrix& train_matrix,
                               size_t outcome_index,
-                              Rcpp::NumericMatrix test_matrix,
-                              Eigen::SparseMatrix<double> sparse_test_matrix,
+                              const Rcpp::NumericMatrix& test_matrix,
                               unsigned int num_threads,
                               unsigned int estimate_variance) {
-  std::unique_ptr<Data> train_data = RcppUtilities::convert_data(train_matrix, sparse_train_matrix);
-  train_data->set_outcome_index(outcome_index - 1);
+  Data train_data = RcppUtilities::convert_data(train_matrix);
+  train_data.set_outcome_index(outcome_index);
 
-  std::unique_ptr<Data> data = RcppUtilities::convert_data(test_matrix, sparse_test_matrix);
+  Data data = RcppUtilities::convert_data(test_matrix);
   Forest forest = RcppUtilities::deserialize_forest(forest_object);
 
   ForestPredictor predictor = regression_predictor(num_threads);
-  std::vector<Prediction> predictions = predictor.predict(forest, *train_data, *data, estimate_variance);
+  std::vector<Prediction> predictions = predictor.predict(forest, train_data, data, estimate_variance);
 
   return RcppUtilities::create_prediction_object(predictions);
 }
 
 // [[Rcpp::export]]
-Rcpp::List regression_predict_oob(Rcpp::List forest_object,
-                                  Rcpp::NumericMatrix train_matrix,
-                                  Eigen::SparseMatrix<double> sparse_train_matrix,
+Rcpp::List regression_predict_oob(const Rcpp::List& forest_object,
+                                  const Rcpp::NumericMatrix& train_matrix,
                                   size_t outcome_index,
                                   unsigned int num_threads,
                                   bool estimate_variance) {
-  std::unique_ptr<Data> data = RcppUtilities::convert_data(train_matrix, sparse_train_matrix);
-  data->set_outcome_index(outcome_index - 1);
+  Data data = RcppUtilities::convert_data(train_matrix);
+  data.set_outcome_index(outcome_index);
 
   Forest forest = RcppUtilities::deserialize_forest(forest_object);
 
   ForestPredictor predictor = regression_predictor(num_threads);
-  std::vector<Prediction> predictions = predictor.predict_oob(forest, *data, estimate_variance);
+  std::vector<Prediction> predictions = predictor.predict_oob(forest, data, estimate_variance);
 
   Rcpp::List result = RcppUtilities::create_prediction_object(predictions);
   return result;
 }
 
 // [[Rcpp::export]]
-Rcpp::List ll_regression_train(Rcpp::NumericMatrix train_matrix,
-                            Eigen::SparseMatrix<double> sparse_train_matrix,
+Rcpp::List ll_regression_train(const Rcpp::NumericMatrix& train_matrix,
                             size_t outcome_index,
-                            size_t sample_weight_index,
                             double ll_split_lambda,
                             bool ll_split_weight_penalty,
                             std::vector<size_t> ll_split_variables,
                             size_t ll_split_cutoff,
                             std::vector<double> overall_beta,
-                            bool use_sample_weights,
                             unsigned int mtry,
                             unsigned int num_trees,
                             unsigned int min_node_size,
@@ -138,64 +128,58 @@ Rcpp::List ll_regression_train(Rcpp::NumericMatrix train_matrix,
   ForestTrainer trainer = ll_regression_trainer(ll_split_lambda, ll_split_weight_penalty, overall_beta,
                                                ll_split_cutoff, ll_split_variables);
 
-  std::unique_ptr<Data> data = RcppUtilities::convert_data(train_matrix, sparse_train_matrix);
-  data->set_outcome_index(outcome_index - 1);
-  if(use_sample_weights) {
-    data->set_weight_index(sample_weight_index - 1);
-  }
+  Data data = RcppUtilities::convert_data(train_matrix);
+  data.set_outcome_index(outcome_index);
 
   ForestOptions options(num_trees, ci_group_size, sample_fraction, mtry, min_node_size, honesty,
                         honesty_fraction, honesty_prune_leaves, alpha, imbalance_penalty, num_threads, seed, clusters, samples_per_cluster);
-  Forest forest = trainer.train(*data, options);
+  Forest forest = trainer.train(data, options);
 
   std::vector<Prediction> predictions;
   return RcppUtilities::create_forest_object(forest, predictions);
 }
 
 // [[Rcpp::export]]
-Rcpp::List ll_regression_predict(Rcpp::List forest_object,
-                                Rcpp::NumericMatrix train_matrix,
-                                Eigen::SparseMatrix<double> sparse_train_matrix,
+Rcpp::List ll_regression_predict(const Rcpp::List& forest_object,
+                                const Rcpp::NumericMatrix& train_matrix,
                                 size_t outcome_index,
-                                Rcpp::NumericMatrix test_matrix,
-                                Eigen::SparseMatrix<double> sparse_test_matrix,
+                                const Rcpp::NumericMatrix& test_matrix,
                                 std::vector<double> ll_lambda,
                                 bool ll_weight_penalty,
                                 std::vector<size_t> linear_correction_variables,
                                 unsigned int num_threads,
                                 bool estimate_variance) {
-  std::unique_ptr<Data> train_data = RcppUtilities::convert_data(train_matrix, sparse_train_matrix);
-  train_data->set_outcome_index(outcome_index - 1);
-  std::unique_ptr<Data> data = RcppUtilities::convert_data(test_matrix, sparse_test_matrix);
+  Data train_data = RcppUtilities::convert_data(train_matrix);
+  train_data.set_outcome_index(outcome_index);
+  Data data = RcppUtilities::convert_data(test_matrix);
 
   Forest deserialized_forest = RcppUtilities::deserialize_forest(forest_object);
 
   ForestPredictor predictor = ll_regression_predictor(num_threads,
       ll_lambda, ll_weight_penalty, linear_correction_variables);
-  std::vector<Prediction> predictions = predictor.predict(deserialized_forest, *train_data, *data, estimate_variance);
+  std::vector<Prediction> predictions = predictor.predict(deserialized_forest, train_data, data, estimate_variance);
   Rcpp::List result = RcppUtilities::create_prediction_object(predictions);
 
   return result;
 }
 
 // [[Rcpp::export]]
-Rcpp::List ll_regression_predict_oob(Rcpp::List forest_object,
-                                    Rcpp::NumericMatrix train_matrix,
-                                    Eigen::SparseMatrix<double> sparse_train_matrix,
+Rcpp::List ll_regression_predict_oob(const Rcpp::List& forest_object,
+                                    const Rcpp::NumericMatrix& train_matrix,
                                     size_t outcome_index,
                                     std::vector<double> ll_lambda,
                                     bool ll_weight_penalty,
                                     std::vector<size_t> linear_correction_variables,
                                     unsigned int num_threads,
                                     bool estimate_variance) {
-  std::unique_ptr<Data> data = RcppUtilities::convert_data(train_matrix, sparse_train_matrix);
-  data->set_outcome_index(outcome_index - 1);
+  Data data = RcppUtilities::convert_data(train_matrix);
+  data.set_outcome_index(outcome_index);
 
   Forest deserialized_forest = RcppUtilities::deserialize_forest(forest_object);
 
   ForestPredictor predictor = ll_regression_predictor(num_threads,
       ll_lambda, ll_weight_penalty, linear_correction_variables);
-  std::vector<Prediction> predictions = predictor.predict_oob(deserialized_forest, *data, estimate_variance);
+  std::vector<Prediction> predictions = predictor.predict_oob(deserialized_forest, data, estimate_variance);
   Rcpp::List result = RcppUtilities::create_prediction_object(predictions);
 
   return result;
